@@ -239,8 +239,8 @@ ma_r_bb <- ma_r_barebones <- function(r, n, n_adj = NULL, sample_id = NULL, cite
                                    residual = r - mean_r_xy, stringsAsFactors = FALSE)
           if("pi" %in% colnames(data)) escalc_obj$pi <- data$pi
           if("pa" %in% colnames(data)) escalc_obj$pa <- data$pa
-          if(!is.null(citekey)) escalc_obj <- cbind(citekey = citekey, escalc_obj) %>% mutate(citekey = as.character(citekey))
-          if(!is.null(sample_id)) escalc_obj <- cbind(sample_id = sample_id, escalc_obj) %>% mutate(sample_id = as.character(sample_id))
+          if(!is.null(citekey)) escalc_obj <- cbind(citekey = citekey, escalc_obj)
+          if(!is.null(sample_id)) escalc_obj <- cbind(sample_id = sample_id, escalc_obj)
           if(any(colnames(data) == "original_order")) escalc_obj <- cbind(original_order = data$original_order, escalc_obj)
           class(escalc_obj) <- c("escalc", "data.frame")
      }
